/* Chrome Cap - Client Styles */

:root {
    --primary-color: #2962ff;
    --secondary-color: #0039cb;
    --background-color: #f5f5f5;
    --card-color: #ffffff;
    --text-color: #333333;
    --light-text: #666666;
    --success-color: #4caf50;
    --error-color: #f44336;
    --border-radius: 8px;
    --shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
}

* {
    box-sizing: border-box;
    margin: 0;
    padding: 0;
}

body {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen,
        Ubuntu, Cantarell, "Open Sans", "Helvetica Neue", sans-serif;
    background-color: var(--background-color);
    color: var(--text-color);
    line-height: 1.6;
    padding: 20px;
    min-height: 100vh;
    display: flex;
    justify-content: center;
    align-items: flex-start;
}

.container {
    max-width: 800px;
    width: 100%;
    background-color: var(--card-color);
    border-radius: var(--border-radius);
    box-shadow: var(--shadow);
    padding: 30px;
    margin-top: 30px;
}

.header {
    text-align: center;
    margin-bottom: 30px;
}

.header h1 {
    font-size: 2.5rem;
    color: var(--primary-color);
    margin-bottom: 5px;
}

.header p {
    color: var(--light-text);
    font-size: 1.1rem;
}

.status-panel {
    margin-bottom: 25px;
    padding: 15px;
    background-color: var(--background-color);
    border-radius: var(--border-radius);
}

.status-indicator {
    display: flex;
    align-items: center;
}

.status-icon {
    width: 20px;
    height: 20px;
    border-radius: 50%;
    margin-right: 10px;
    background-color: #999;
}

.status-text {
    font-weight: 500;
}

/* Status states */
.status-indicator.checking .status-icon {
    background-color: #ffc107;
    animation: pulse 1.5s infinite;
}

.status-indicator.ready .status-icon {
    background-color: #2196f3;
}

.status-indicator.capturing .status-icon {
    background-color: #9c27b0;
    animation: pulse 1s infinite;
}

.status-indicator.success .status-icon {
    background-color: var(--success-color);
}

.status-indicator.error .status-icon {
    background-color: var(--error-color);
}

@keyframes pulse {
    0% {
        transform: scale(1);
        opacity: 1;
    }
    50% {
        transform: scale(1.1);
        opacity: 0.7;
    }
    100% {
        transform: scale(1);
        opacity: 1;
    }
}

.target-url {
    margin-bottom: 25px;
}

.target-url h2 {
    font-size: 1.2rem;
    margin-bottom: 10px;
    color: var(--light-text);
}

.target-url p {
    font-size: 1.1rem;
    word-break: break-all;
    padding: 12px;
    background-color: var(--background-color);
    border-radius: var(--border-radius);
}

.action-panel {
    display: flex;
    justify-content: space-between;
    margin-bottom: 30px;
}

.btn {
    padding: 12px 24px;
    background-color: var(--primary-color);
    color: white;
    border: none;
    border-radius: var(--border-radius);
    font-size: 1rem;
    font-weight: 500;
    cursor: pointer;
    transition: background-color 0.2s;
}

.btn:hover {
    background-color: var(--secondary-color);
}

.btn.secondary {
    background-color: #e0e0e0;
    color: var(--text-color);
}

.btn.secondary:hover {
    background-color: #d0d0d0;
}

.result-panel, .error-panel {
    margin-top: 30px;
    padding: 20px;
    border-radius: var(--border-radius);
}

.result-panel {
    background-color: rgba(76, 175, 80, 0.1);
}

.error-panel {
    background-color: rgba(244, 67, 54, 0.1);
}

.hidden {
    display: none;
}

.thumbnail {
    margin: 20px 0;
    text-align: center;
}

.thumbnail img {
    max-width: 100%;
    max-height: 400px;
    border: 1px solid #ddd;
    border-radius: var(--border-radius);
    box-shadow: var(--shadow);
}

.result-info {
    margin-bottom: 20px;
}

.result-info p {
    margin-bottom: 8px;
}

.result-actions {
    display: flex;
    justify-content: space-between;
}

#error-message {
    margin-bottom: 15px;
    font-weight: 500;
}

/* Responsive styles */
@media (max-width: 600px) {
    .container {
        padding: 20px;
        margin-top: 15px;
    }
    
    .header h1 {
        font-size: 2rem;
    }
    
    .action-panel {
        flex-direction: column;
        gap: 10px;
    }
    
    .result-actions {
        flex-direction: column;
        gap: 10px;
    }
    
    .btn {
        width: 100%;
    }
} 